@@ -362,29 +362,29 @@ class BaseCRUDView(BaseModelView):
     add_form_query_rel_fields = None
     """
         Add Customized query for related fields on add form.
-        Assign a tuble like ('relation col name',SQLAModel,[['Related model col',FilterClass,'Filter Value'],...])
+        Assign a list of tuples like ('relation col name',SQLAModel,[['Related model col',FilterClass,'Filter Value'],...])
         Add a custom filter to form related fields::
 
-        class ContactGeneralView(GeneralView):
-            datamodel = SQLAModel(Contact, db.session)
-            add_form_query_rel_fields = ('group',
+            class ContactGeneralView(GeneralView):
+                datamodel = SQLAModel(Contact, db.session)
+                add_form_query_rel_fields = [('group',
                         SQLAModel(Group, db.session),
                         [['name',FilterStartsWith,'W']]
-                        )
+                        )]
 
     """
     edit_form_query_rel_fields = None
     """
         Add Customized query for related fields on edit form.
-        Assign a tuble like ('relation col name',SQLAModel,[['Related model col',FilterClass,'Filter Value'],...])
+        Assign a list of tuples like ('relation col name',SQLAModel,[['Related model col',FilterClass,'Filter Value'],...])
         Add a custom filter to form related fields::
 
-        class ContactGeneralView(GeneralView):
-            datamodel = SQLAModel(Contact, db.session)
-            edit_form_query_rel_fields = ('group',
+            class ContactGeneralView(GeneralView):
+                datamodel = SQLAModel(Contact, db.session)
+                edit_form_query_rel_fields = [('group',
                         SQLAModel(Group, db.session),
                         [['name',FilterStartsWith,'W']]
-                        )
+                        )]
 
     """
 
